EXPORTS
	?AddAttendeeL@CEntryAttributes@@QAEXPAVCAttendeeInfo@@@Z @ 1 NONAME ; void CEntryAttributes::AddAttendeeL(class CAttendeeInfo *)
	?AddExceptionDateL@CEntryAttributes@@QAEXABVTTime@@@Z @ 2 NONAME ; void CEntryAttributes::AddExceptionDateL(class TTime const &)
	?AddGuidL@CCalendarExportParams@@QAEXABVTDesC8@@@Z @ 3 NONAME ; void CCalendarExportParams::AddGuidL(class TDesC8 const &)
	?AddGuidL@CCalendarExportParams@@QAEXPBVCDesC8Array@@@Z @ 4 NONAME ; void CCalendarExportParams::AddGuidL(class CDesC8Array const *)
	?AddGuidL@CCalendarFilter@@QAEXABVTDesC8@@@Z @ 5 NONAME ; void CCalendarFilter::AddGuidL(class TDesC8 const &)
	?AddL@CCalendarService@@QAEXABVTDesC16@@@Z @ 6 NONAME ; void CCalendarService::AddL(class TDesC16 const &)
	?AddL@CCalendarService@@QAEXABVTDesC16@@PAVCEntryAttributes@@AAPAUTUIDSet@@@Z @ 7 NONAME ; void CCalendarService::AddL(class TDesC16 const &, class CEntryAttributes *, struct TUIDSet * &)
	?AddLocalUid@CCalendarExportParams@@QAEXABV?$RArray@K@@@Z @ 8 NONAME ; void CCalendarExportParams::AddLocalUid(class RArray<unsigned long> const &)
	?AddLocalUid@CCalendarExportParams@@QAEXK@Z @ 9 NONAME ; void CCalendarExportParams::AddLocalUid(unsigned long)
	?AddLocalUid@CCalendarFilter@@QAEXK@Z @ 10 NONAME ; void CCalendarFilter::AddLocalUid(unsigned long)
	?AddRepeatDateL@CEntryAttributes@@QAEXABVTTime@@@Z @ 11 NONAME ; void CEntryAttributes::AddRepeatDateL(class TTime const &)
	?Address@CAttendeeInfo@@QAE?AVTPtrC16@@XZ @ 12 NONAME ; class TPtrC16 CAttendeeInfo::Address(void)
	?AlarmTime@CEntryAttributes@@QAE?AVTTime@@XZ @ 13 NONAME ; class TTime CEntryAttributes::AlarmTime(void)
	?AttendeeList@CEntryAttributes@@QAEAAV?$RPointerArray@VCCalAttendee@@@@XZ @ 14 NONAME ; class RPointerArray<class CCalAttendee> & CEntryAttributes::AttendeeList(void)
	?Cancel@CAsyncRequestObserver@@QAEHJ@Z @ 15 NONAME ; int CAsyncRequestObserver::Cancel(long)
	?Cancel@CCalendarService@@QAEHJ@Z @ 16 NONAME ; int CCalendarService::Cancel(long)
	?CloneL@CCalendarExportParams@@QAEPAV1@XZ @ 17 NONAME ; class CCalendarExportParams * CCalendarExportParams::CloneL(void)
	?CommonName@CAttendeeInfo@@QAE?AVTPtrC16@@XZ @ 18 NONAME ; class TPtrC16 CAttendeeInfo::CommonName(void)
	?DatesInMonth@CRepeatInfo@@QAEAAV?$RArray@H@@XZ @ 19 NONAME ; class RArray<int> & CRepeatInfo::DatesInMonth(void)
	?DaysInMonth@CRepeatInfo@@QAEAAV?$RArray@VTDayOfMonth@TCalRRule@@@@XZ @ 20 NONAME ; class RArray<class TCalRRule::TDayOfMonth> & CRepeatInfo::DaysInMonth(void)
	?DaysInWeek@CRepeatInfo@@QAEAAV?$RArray@W4TDay@@@@XZ @ 21 NONAME ; class RArray<enum TDay> & CRepeatInfo::DaysInWeek(void)
	?DeleteL@CCalendarService@@QAEXABVTDesC16@@@Z @ 22 NONAME ; void CCalendarService::DeleteL(class TDesC16 const &)
	?DeleteL@CCalendarService@@QAEXABVTDesC16@@PAVCCalendarFilter@@PAVMCalCallbackBase@@@Z @ 23 NONAME ; void CCalendarService::DeleteL(class TDesC16 const &, class CCalendarFilter *, class MCalCallbackBase *)
	?Description@CEntryAttributes@@QAE?AVTPtrC16@@XZ @ 24 NONAME ; class TPtrC16 CEntryAttributes::Description(void)
	?EndTime@CEntryAttributes@@QAEAAVTCalTime@@XZ @ 25 NONAME ; class TCalTime & CEntryAttributes::EndTime(void)
	?EntryStatus@CEntryAttributes@@QAE?AW4TStatus@CCalEntry@@XZ @ 26 NONAME ; enum CCalEntry::TStatus CEntryAttributes::EntryStatus(void)
	?EntryType@CEntryAttributes@@QAE?AW4TType@CCalEntry@@XZ @ 27 NONAME ; enum CCalEntry::TType CEntryAttributes::EntryType(void)
	?ExceptionDates@CEntryAttributes@@QAEAAV?$RArray@VTCalTime@@@@XZ @ 28 NONAME ; class RArray<class TCalTime> & CEntryAttributes::ExceptionDates(void)
	?ExportFileName@CCalendarExportParams@@QAE?AVTPtrC16@@XZ @ 29 NONAME ; class TPtrC16 CCalendarExportParams::ExportFileName(void)
	?ExportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@PAVCCalendarExportParams@@AAPAVHBufC8@@@Z @ 30 NONAME ; void CCalendarService::ExportL(class TDesC16 const &, class TDesC8 const &, class CCalendarExportParams *, class HBufC8 * &)
	?ExportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@PAVCCalendarExportParams@@PAVMCalCallbackBase@@@Z @ 31 NONAME ; void CCalendarService::ExportL(class TDesC16 const &, class TDesC8 const &, class CCalendarExportParams *, class MCalCallbackBase *)
	?Filter@CCalendarFilter@@QBEJXZ @ 32 NONAME ; long CCalendarFilter::Filter(void) const
	?FilterText@CCalendarFilter@@QBE?AVTPtrC16@@XZ @ 33 NONAME ; class TPtrC16 CCalendarFilter::FilterText(void) const
	?FilterType@CCalendarFilter@@QBEIXZ @ 34 NONAME ; unsigned int CCalendarFilter::FilterType(void) const
	?GetListL@CCalendarService@@QAEXAAPAVCDesC16Array@@H@Z @ 35 NONAME ; void CCalendarService::GetListL(class CDesC16Array * &, int)
	?GetListL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@AAV?$RPointerArray@VCCalEntry@@@@@Z @ 36 NONAME ; void CCalendarService::GetListL(class TDesC16 const &, class TDesC8 const &, class RPointerArray<class CCalEntry> &)
	?GetListL@CCalendarService@@QAEXABVTDesC16@@KAAV?$RPointerArray@VCCalEntry@@@@@Z @ 37 NONAME ; void CCalendarService::GetListL(class TDesC16 const &, unsigned long, class RPointerArray<class CCalEntry> &)
	?GetListL@CCalendarService@@QAEXABVTDesC16@@PAVCCalendarFilter@@AAV?$RPointerArray@VCCalInstance@@@@@Z @ 38 NONAME ; void CCalendarService::GetListL(class TDesC16 const &, class CCalendarFilter *, class RPointerArray<class CCalInstance> &)
	?GetRepeatRule@CRepeatInfo@@QAEAAVTCalRRule@@XZ @ 39 NONAME ; class TCalRRule & CRepeatInfo::GetRepeatRule(void)
	?GuidArray@CCalendarExportParams@@QBEPBVCDesC8Array@@XZ @ 40 NONAME ; class CDesC8Array const * CCalendarExportParams::GuidArray(void) const
	?GuidList@CCalendarFilter@@QBEPBVCDesC8Array@@XZ @ 41 NONAME ; class CDesC8Array const * CCalendarFilter::GuidList(void) const
	?ImportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@0AAV?$RPointerArray@UTUIDSet@@@@@Z @ 42 NONAME ; void CCalendarService::ImportL(class TDesC16 const &, class TDesC8 const &, class TDesC16 const &, class RPointerArray<struct TUIDSet> &)
	?ImportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@0PAVMCalCallbackBase@@@Z @ 43 NONAME ; void CCalendarService::ImportL(class TDesC16 const &, class TDesC8 const &, class TDesC16 const &, class MCalCallbackBase *)
	?ImportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@1AAV?$RPointerArray@UTUIDSet@@@@@Z @ 44 NONAME ; void CCalendarService::ImportL(class TDesC16 const &, class TDesC8 const &, class TDesC8 const &, class RPointerArray<struct TUIDSet> &)
	?ImportL@CCalendarService@@QAEXABVTDesC16@@ABVTDesC8@@1PAVMCalCallbackBase@@@Z @ 45 NONAME ; void CCalendarService::ImportL(class TDesC16 const &, class TDesC8 const &, class TDesC8 const &, class MCalCallbackBase *)
	?InstanceStartTime@CEntryAttributes@@QAEAAVTCalTime@@XZ @ 46 NONAME ; class TCalTime & CEntryAttributes::InstanceStartTime(void)
	?Interval@CRepeatInfo@@QAEHXZ @ 47 NONAME ; int CRepeatInfo::Interval(void)
	?LocalUid@CEntryAttributes@@QAEKXZ @ 48 NONAME ; unsigned long CEntryAttributes::LocalUid(void)
	?LocalUidArray@CCalendarExportParams@@QBEABV?$RArray@K@@XZ @ 49 NONAME ; class RArray<unsigned long> const & CCalendarExportParams::LocalUidArray(void) const
	?LocalUidList@CCalendarFilter@@QBEABV?$RArray@K@@XZ @ 50 NONAME ; class RArray<unsigned long> const & CCalendarFilter::LocalUidList(void) const
	?Location@CEntryAttributes@@QAE?AVTPtrC16@@XZ @ 51 NONAME ; class TPtrC16 CEntryAttributes::Location(void)
	?Method@CEntryAttributes@@QAE?AW4TMethod@CCalEntry@@XZ @ 52 NONAME ; enum CCalEntry::TMethod CEntryAttributes::Method(void)
	?ModifiedAttributes@CEntryAttributes@@QAEJXZ @ 53 NONAME ; long CEntryAttributes::ModifiedAttributes(void)
	?Month@CRepeatInfo@@QAE?AW4TMonth@@XZ @ 54 NONAME ; enum TMonth CRepeatInfo::Month(void)
	?NewL@CAttendeeInfo@@SAPAV1@ABVTDesC16@@@Z @ 55 NONAME ; class CAttendeeInfo * CAttendeeInfo::NewL(class TDesC16 const &)
	?NewL@CCalendarExportParams@@SAPAV1@XZ @ 56 NONAME ; class CCalendarExportParams * CCalendarExportParams::NewL(void)
	?NewL@CCalendarFilter@@SAPAV1@XZ @ 57 NONAME ; class CCalendarFilter * CCalendarFilter::NewL(void)
	?NewL@CCalendarService@@SAPAV1@XZ @ 58 NONAME ; class CCalendarService * CCalendarService::NewL(void)
	?NewL@CEntryAttributes@@SAPAV1@ABVTDesC16@@@Z @ 59 NONAME ; class CEntryAttributes * CEntryAttributes::NewL(class TDesC16 const &)
	?NewL@CEntryAttributes@@SAPAV1@XZ @ 60 NONAME ; class CEntryAttributes * CEntryAttributes::NewL(void)
	?NewL@CRepeatInfo@@SAPAV1@H@Z @ 61 NONAME ; class CRepeatInfo * CRepeatInfo::NewL(int)
	?Organizer@CEntryAttributes@@QAEPAVCCalUser@@XZ @ 62 NONAME ; class CCalUser * CEntryAttributes::Organizer(void)
	?Params@CCalendarExportParams@@QBEJXZ @ 63 NONAME ; long CCalendarExportParams::Params(void) const
	?PhoneOwner@CEntryAttributes@@QAE?AVTPtrC16@@XZ @ 64 NONAME ; class TPtrC16 CEntryAttributes::PhoneOwner(void)
	?Priority@CEntryAttributes@@QAEHXZ @ 65 NONAME ; int CEntryAttributes::Priority(void)
	?RepeatDates@CEntryAttributes@@QAEAAV?$RArray@VTCalTime@@@@XZ @ 66 NONAME ; class RArray<class TCalTime> & CEntryAttributes::RepeatDates(void)
	?RepeatRuleL@CEntryAttributes@@QAEAAVTCalRRule@@XZ @ 67 NONAME ; class TCalRRule & CEntryAttributes::RepeatRuleL(void)
	?ReplicationStatus@CEntryAttributes@@QAE?AW4TReplicationStatus@CCalEntry@@XZ @ 68 NONAME ; enum CCalEntry::TReplicationStatus CEntryAttributes::ReplicationStatus(void)
	?ResponseRequested@CAttendeeInfo@@QAEHXZ @ 69 NONAME ; int CAttendeeInfo::ResponseRequested(void)
	?Role@CAttendeeInfo@@QAE?AVTPtrC16@@XZ @ 70 NONAME ; class TPtrC16 CAttendeeInfo::Role(void)
	?SequenceNumber@CEntryAttributes@@QAEHXZ @ 71 NONAME ; int CEntryAttributes::SequenceNumber(void)
	?SetAlarm@CEntryAttributes@@QAEXABVTTime@@@Z @ 72 NONAME ; void CEntryAttributes::SetAlarm(class TTime const &)
	?SetCommonNameL@CAttendeeInfo@@QAEXABVTDesC16@@@Z @ 73 NONAME ; void CAttendeeInfo::SetCommonNameL(class TDesC16 const &)
	?SetCount@CRepeatInfo@@QAEXI@Z @ 74 NONAME ; void CRepeatInfo::SetCount(unsigned int)
	?SetDaysInWeek@CRepeatInfo@@QAEXABV?$RArray@W4TDay@@@@@Z @ 75 NONAME ; void CRepeatInfo::SetDaysInWeek(class RArray<enum TDay> const &)
	?SetDeleteAll@CCalendarFilter@@QAEXH@Z @ 76 NONAME ; void CCalendarFilter::SetDeleteAll(int)
	?SetDescriptionL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 77 NONAME ; void CEntryAttributes::SetDescriptionL(class TDesC16 const &)
	?SetEndTimeL@CCalendarFilter@@QAEXABVTTime@@@Z @ 78 NONAME ; void CCalendarFilter::SetEndTimeL(class TTime const &)
	?SetEndTimeL@CEntryAttributes@@QAEXABVTTime@@@Z @ 79 NONAME ; void CEntryAttributes::SetEndTimeL(class TTime const &)
	?SetEntryStatusL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 80 NONAME ; void CEntryAttributes::SetEntryStatusL(class TDesC16 const &)
	?SetExportFileNameL@CCalendarExportParams@@QAEXABVTDesC16@@@Z @ 81 NONAME ; void CCalendarExportParams::SetExportFileNameL(class TDesC16 const &)
	?SetFilterTextL@CCalendarFilter@@QAEXABVTDesC16@@@Z @ 82 NONAME ; void CCalendarFilter::SetFilterTextL(class TDesC16 const &)
	?SetFilterTypeL@CCalendarFilter@@QAEXABVTDesC16@@@Z @ 83 NONAME ; void CCalendarFilter::SetFilterTypeL(class TDesC16 const &)
	?SetIncludeUnDateToDo@CCalendarFilter@@QAEXH@Z @ 84 NONAME ; void CCalendarFilter::SetIncludeUnDateToDo(int)
	?SetInstanceStartTimeL@CEntryAttributes@@QAEXABVTTime@@@Z @ 85 NONAME ; void CEntryAttributes::SetInstanceStartTimeL(class TTime const &)
	?SetInterval@CRepeatInfo@@QAEXH@Z @ 86 NONAME ; void CRepeatInfo::SetInterval(int)
	?SetLocalUid@CEntryAttributes@@QAEXK@Z @ 87 NONAME ; void CEntryAttributes::SetLocalUid(unsigned long)
	?SetLocationL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 88 NONAME ; void CEntryAttributes::SetLocationL(class TDesC16 const &)
	?SetMethodL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 89 NONAME ; void CEntryAttributes::SetMethodL(class TDesC16 const &)
	?SetMonth@CRepeatInfo@@QAEXH@Z @ 90 NONAME ; void CRepeatInfo::SetMonth(int)
	?SetMonthDates@CRepeatInfo@@QAEXABV?$RArray@H@@@Z @ 91 NONAME ; void CRepeatInfo::SetMonthDates(class RArray<int> const &)
	?SetMonthDays@CRepeatInfo@@QAEXABV?$RArray@VTDayOfMonth@TCalRRule@@@@@Z @ 92 NONAME ; void CRepeatInfo::SetMonthDays(class RArray<class TCalRRule::TDayOfMonth> const &)
	?SetOrganizerDataL@CEntryAttributes@@QAEXPAVCAttendeeInfo@@@Z @ 93 NONAME ; void CEntryAttributes::SetOrganizerDataL(class CAttendeeInfo *)
	?SetPhoneOwnerDataL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 94 NONAME ; void CEntryAttributes::SetPhoneOwnerDataL(class TDesC16 const &)
	?SetPriority@CEntryAttributes@@QAEHH@Z @ 95 NONAME ; int CEntryAttributes::SetPriority(int)
	?SetRepeatRule@CEntryAttributes@@QAEXPAVCRepeatInfo@@@Z @ 96 NONAME ; void CEntryAttributes::SetRepeatRule(class CRepeatInfo *)
	?SetReplicationL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 97 NONAME ; void CEntryAttributes::SetReplicationL(class TDesC16 const &)
	?SetRoleL@CAttendeeInfo@@QAEXABVTDesC16@@@Z @ 98 NONAME ; void CAttendeeInfo::SetRoleL(class TDesC16 const &)
	?SetRsvp@CAttendeeInfo@@QAEXH@Z @ 99 NONAME ; void CAttendeeInfo::SetRsvp(int)
	?SetSequenceNumber@CEntryAttributes@@QAEXH@Z @ 100 NONAME ; void CEntryAttributes::SetSequenceNumber(int)
	?SetStartTimeL@CCalendarFilter@@QAEXABVTTime@@@Z @ 101 NONAME ; void CCalendarFilter::SetStartTimeL(class TTime const &)
	?SetStartTimeL@CEntryAttributes@@QAEXABVTTime@@@Z @ 102 NONAME ; void CEntryAttributes::SetStartTimeL(class TTime const &)
	?SetStartTimeL@CRepeatInfo@@QAEXABVTTime@@@Z @ 103 NONAME ; void CRepeatInfo::SetStartTimeL(class TTime const &)
	?SetStatusL@CAttendeeInfo@@QAEXABVTDesC16@@@Z @ 104 NONAME ; void CAttendeeInfo::SetStatusL(class TDesC16 const &)
	?SetSummaryL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 105 NONAME ; void CEntryAttributes::SetSummaryL(class TDesC16 const &)
	?SetTypeL@CEntryAttributes@@QAEXABVTDesC16@@@Z @ 106 NONAME ; void CEntryAttributes::SetTypeL(class TDesC16 const &)
	?SetUntilTimeL@CRepeatInfo@@QAEXABVTTime@@@Z @ 107 NONAME ; void CRepeatInfo::SetUntilTimeL(class TTime const &)
	?SetWeekStart@CRepeatInfo@@QAEXH@Z @ 108 NONAME ; void CRepeatInfo::SetWeekStart(int)
	?StartChangeNotifyL@CCalendarService@@QAEXABVTDesC16@@PAVCCalendarFilter@@PAVMCalCallbackBase@@@Z @ 109 NONAME ; void CCalendarService::StartChangeNotifyL(class TDesC16 const &, class CCalendarFilter *, class MCalCallbackBase *)
	?StartTime@CEntryAttributes@@QAEAAVTCalTime@@XZ @ 110 NONAME ; class TCalTime & CEntryAttributes::StartTime(void)
	?Status@CAttendeeInfo@@QAE?AVTPtrC16@@XZ @ 111 NONAME ; class TPtrC16 CAttendeeInfo::Status(void)
	?Summary@CEntryAttributes@@QAE?AVTPtrC16@@XZ @ 112 NONAME ; class TPtrC16 CEntryAttributes::Summary(void)
	?TimeRange@CCalendarFilter@@QBE?AVTCalTimeRange@CalCommon@@XZ @ 113 NONAME ; class CalCommon::TCalTimeRange CCalendarFilter::TimeRange(void) const
	?Type@CRepeatInfo@@QAE?AW4TType@TCalRRule@@XZ @ 114 NONAME ; enum TCalRRule::TType CRepeatInfo::Type(void)
	?UntilDate@CRepeatInfo@@QAEAAVTCalTime@@XZ @ 115 NONAME ; class TCalTime & CRepeatInfo::UntilDate(void)
	?WeekStart@CRepeatInfo@@QAE?AW4TDay@@XZ @ 116 NONAME ; enum TDay CRepeatInfo::WeekStart(void)

